@@ -55,7 +55,7 @@ from lollypop.helper_art import ArtHelper
 from lollypop.collectionscanner import CollectionScanner
 
 
-class Application(Gtk.Application):
+class Application(Gtk.Application, ApplicationActions):
     """
         Lollypop application:
             - Handle appmenu
@@ -199,11 +199,12 @@ class Application(Gtk.Application):
         if not self.__gtk_dark:
             dark = self.settings.get_value("dark-ui")
             settings.set_property("gtk-application-prefer-dark-theme", dark)
-        ApplicationActions()
+        ApplicationActions.__init__(self)
         startup_one_ids = self.settings.get_value("startup-one-ids")
         startup_two_ids = self.settings.get_value("startup-two-ids")
         if startup_one_ids:
             self.settings.set_value("state-one-ids", startup_one_ids)
+            self.settings.set_value("state-three-ids", GLib.Variant("ai", []))
         if startup_two_ids:
             self.settings.set_value("state-two-ids", startup_two_ids)
 
@@ -225,7 +226,22 @@ class Application(Gtk.Application):
             Quit Lollypop
             @param vacuum as bool
         """
-        if not self.settings.get_value("save-state"):
+        if self.settings.get_value("save-state"):
+            # Special case, we can't handle this earlier
+            if self.window.is_adaptive:
+                visible = self.window.container.stack.get_visible_child()
+                if visible == self.window.container.list_one:
+                    self.settings.set_value("state-one-ids",
+                                            GLib.Variant("ai", []))
+                    self.settings.set_value("state-two-ids",
+                                            GLib.Variant("ai", []))
+                elif visible == self.window.container.list_two:
+                    selected_ids = self.window.container.list_one.selected_ids
+                    self.settings.set_value("state-one-ids",
+                                            GLib.Variant("ai", selected_ids))
+                    self.settings.set_value("state-two-ids",
+                                            GLib.Variant("ai", []))
+        else:
             self.settings.set_value("state-one-ids", GLib.Variant("ai", []))
             self.settings.set_value("state-two-ids", GLib.Variant("ai", []))
         # Then vacuum db
@@ -348,7 +364,7 @@ class Application(Gtk.Application):
 
         if self.player.current_track.id is None or\
                 self.player.current_track.mtime == 0:
-            track_id = -1
+            track_id = None
         elif self.player.current_track.id == Type.RADIOS:
             from lollypop.radios import Radios
             radios = Radios()
@@ -556,8 +572,10 @@ class Application(Gtk.Application):
             @param widget as Gtk.Widget
             @param event as Gdk.Event
         """
+        # Quit if background mode is on but player is off
         if not self.settings.get_value("background-mode") or\
                 not self.player.is_playing:
+            self.player.pause()
             GLib.timeout_add(500, self.quit, True)
         return widget.hide_on_delete()
 
