@@ -83,6 +83,34 @@ class ApplicationActions:
 
         App().scanner.connect("scan-finished", self.__on_scan_finished)
         self.__setup_global_shortcuts()
+        self.enable_special_shortcuts(True)
+
+    def enable_special_shortcuts(self, enable):
+        """
+            Enable special shortcuts
+            @param enable as bool
+        """
+        if enable:
+            if Gtk.Widget.get_default_direction() == Gtk.TextDirection.RTL:
+                App().set_accels_for_action("app.seek(10)", ["Left"])
+                App().set_accels_for_action("app.seek(-10)", ["Right"])
+            else:
+                App().set_accels_for_action("app.seek(10)", ["Right"])
+                App().set_accels_for_action("app.seek(-10)", ["Left"])
+            App().set_accels_for_action("app.shortcut::play_pause",
+                                        ["c", "space"])
+            App().set_accels_for_action("app.shortcut::play", ["x"])
+            App().set_accels_for_action("app.shortcut::stop", ["v"])
+            App().set_accels_for_action("app.shortcut::next", ["n"])
+            App().set_accels_for_action("app.shortcut::prev", ["p"])
+        else:
+            App().set_accels_for_action("app.seek(10)", [])
+            App().set_accels_for_action("app.seek(-10)", [])
+            App().set_accels_for_action("app.shortcut::play_pause", [])
+            App().set_accels_for_action("app.shortcut::play", [])
+            App().set_accels_for_action("app.shortcut::stop", [])
+            App().set_accels_for_action("app.shortcut::next", [])
+            App().set_accels_for_action("app.shortcut::prev", [])
 
 #######################
 # PRIVATE             #
@@ -91,6 +119,12 @@ class ApplicationActions:
         """
             Setup global shortcuts
         """
+        if Gtk.Widget.get_default_direction() == Gtk.TextDirection.RTL:
+            App().set_accels_for_action("app.shortcut::go_back",
+                                        ["<Alt>Right", "Back"])
+        else:
+            App().set_accels_for_action("app.shortcut::go_back",
+                                        ["<Alt>Left", "Back"])
         App().set_accels_for_action("app.shortcut::filter", ["<Control>i"])
         App().set_accels_for_action("app.shortcut::volume",
                                     ["<Shift><Alt>v"])
@@ -108,32 +142,16 @@ class ApplicationActions:
         App().set_accels_for_action("app.shortcuts", ["F2"])
         App().set_accels_for_action("app.help", ["F1"])
         App().set_accels_for_action("app.quit", ["<Control>q"])
-        if Gtk.Widget.get_default_direction() == Gtk.TextDirection.RTL:
-            App().set_accels_for_action("app.seek(10)",
-                                        ["<Shift><Alt>Left"])
-            App().set_accels_for_action("app.seek(-10)",
-                                        ["<Shift><Alt>Right"])
-            App().set_accels_for_action("app.shortcut::go_back",
-                                        ["<Alt>Right", "Back"])
-        else:
-            App().set_accels_for_action("app.seek(10)",
-                                        ["<Shift><Alt>Right"])
-            App().set_accels_for_action("app.seek(-10)",
-                                        ["<Shift><Alt>Left"])
-            App().set_accels_for_action("app.shortcut::go_back",
-                                        ["<Alt>Left", "Back"])
-        App().set_accels_for_action("app.shortcut::play_pause",
-                                    ["<Alt>c"])
-        App().set_accels_for_action("app.shortcut::play", ["<Alt>x"])
-        App().set_accels_for_action("app.shortcut::stop", ["<Alt>v"])
-        App().set_accels_for_action("app.shortcut::next", ["<Alt>n"])
-        App().set_accels_for_action("app.shortcut::prev", ["<Alt>p"])
         App().set_accels_for_action("app.shortcut::loved", ["<Alt>l"])
         App().set_accels_for_action("app.shortcut::reload", ["<Control>r"])
         App().set_accels_for_action("app.shortcut::volume_up",
                                     ["<Shift><Alt>Up"])
         App().set_accels_for_action("app.shortcut::volume_down",
                                     ["<Shift><Alt>Down"])
+        App().set_accels_for_action("app.shortcut::list_one_type_ahead",
+                                    ["<Control>o"])
+        App().set_accels_for_action("app.shortcut::list_two_type_ahead",
+                                    ["<Control>t"])
 
     def __on_update_db_activate(self, action=None, param=None):
         """
@@ -280,6 +298,12 @@ class ApplicationActions:
             App().player.set_volume(App().player.volume + 0.1)
         elif string == "volume_down":
             App().player.set_volume(App().player.volume - 0.1)
+        elif string == "list_one_type_ahead":
+            if App().window.container.list_one.is_visible():
+                App().window.container.list_one.type_ahead_popover.popup()
+        elif string == "list_two_type_ahead":
+            if App().window.container.list_two.is_visible():
+                App().window.container.list_two.type_ahead_popover.popup()
         elif string == "show_sidebar":
             value = App().settings.get_value("show-sidebar")
             App().settings.set_value("show-sidebar",
