@@ -32,10 +32,12 @@ class ListsContainer:
         """
         self._list_one = SelectionList(SelectionListMask.LIST_ONE)
         self._list_two = SelectionList(SelectionListMask.LIST_TWO)
-        self._list_one.connect("item-selected", self.__on_list_one_selected)
+        self._list_one.listbox.connect("row-activated",
+                                       self.__on_list_one_activated)
+        self._list_two.listbox.connect("row-activated",
+                                       self.__on_list_two_activated)
         self._list_one.connect("populated", self.__on_list_one_populated)
         self._list_one.connect("pass-focus", self.__on_pass_focus)
-        self._list_two.connect("item-selected", self.__on_list_two_selected)
         self._list_two.connect("pass-focus", self.__on_pass_focus)
 
     def update_list_one(self, update=False):
@@ -114,32 +116,30 @@ class ListsContainer:
         try:
             state_one_ids = App().settings.get_value("state-one-ids")
             state_two_ids = App().settings.get_value("state-two-ids")
-            if state_two_ids and not state_one_ids:
-                sidebar_content = App().settings.get_enum("sidebar-content")
-                if sidebar_content == SidebarContent.GENRES:
-                    self.show_artists_albums(state_two_ids)
-                    return
-                else:
-                    state_one_ids = state_two_ids
-                    state_two_ids = []
-            if state_two_ids:
-                self._list_two.connect("populated",
-                                       select_list_two,
-                                       state_two_ids)
+            state_three_ids = App().settings.get_value("state-three-ids")
+            # Empty because we do not have any genre set
+            if not state_one_ids:
+                state_one_ids = state_two_ids
+                state_two_ids = state_three_ids
             if state_one_ids:
-                if state_one_ids and state_one_ids[0] == Type.ALBUM:
-                    self._list_one.select_first()
-                    album = Album(state_two_ids[0])
-                    self.show_view([Type.ALBUM], album)
-                # Here we are just handling missing Type.ARTISTS from list
-                elif state_one_ids[0] == Type.ARTISTS:
-                    from lollypop.shown import ShownLists
-                    shown_lists = ShownLists.get(SelectionListMask.LIST_ONE)
-                    ids = [l[0] for l in shown_lists]
-                    if Type.ARTISTS not in ids:
-                        self._list_one.add_value((Type.ARTISTS,
-                                                 _("All artists"), ""))
                 self._list_one.select_ids(state_one_ids)
+                # If list two not available, directly show view
+                sidebar_content = App().settings.get_enum("sidebar-content")
+                if state_two_ids and (
+                                  App().window.is_adaptive or
+                                  sidebar_content == SidebarContent.DEFAULT):
+                    self.show_view(state_one_ids, state_two_ids)
+                # Wait for list to be populated and select item
+                elif state_two_ids and not state_three_ids:
+                    self._list_two.connect("populated",
+                                           select_list_two,
+                                           state_two_ids)
+
+                if state_three_ids:
+                    album = Album(state_three_ids[0],
+                                  state_one_ids,
+                                  state_two_ids)
+                    self.show_view([Type.ALBUM], album)
             elif not App().window.is_adaptive:
                 self._list_one.select_first()
         except Exception as e:
@@ -226,12 +226,13 @@ class ListsContainer:
                         on_finished=lambda r: setup(*r))
         loader.start()
 
-    def __on_list_one_selected(self, selection_list):
+    def __on_list_one_activated(self, listbox, row):
         """
             Update view based on selected object
-            @param list as SelectionList
+            @param listbox as Gtk.ListBox
+            @param row as Gtk.ListBoxRow
         """
-        Logger.debug("Container::__on_list_one_selected()")
+        Logger.debug("Container::__on_list_one_activated()")
         self._stack.destroy_children()
         if App().window.is_adaptive:
             App().window.emit("can-go-back-changed", True)
@@ -275,7 +276,7 @@ class ListsContainer:
             view = self._get_view_genres()
         elif selected_ids[0] == Type.ARTISTS:
             view = self._get_view_artists_rounded(False)
-        elif selection_list.mask & SelectionListMask.ARTISTS:
+        elif self._list_one.mask & SelectionListMask.ARTISTS:
             if selected_ids[0] == Type.ALL:
                 view = self._get_view_albums(selected_ids, [])
             elif selected_ids[0] == Type.COMPILATIONS:
@@ -302,12 +303,13 @@ class ListsContainer:
         """
         pass
 
-    def __on_list_two_selected(self, selection_list):
+    def __on_list_two_activated(self, listbox, row):
         """
             Update view based on selected object
-            @param selection_list as SelectionList
+            @param listbox as Gtk.ListBox
+            @param row as Gtk.ListBoxRow
         """
-        Logger.debug("Container::__on_list_two_selected()")
+        Logger.debug("Container::__on_list_two_activated()")
         self._stack.destroy_children()
         if not App().window.is_adaptive:
             App().window.emit("show-can-go-back", False)
