@@ -100,6 +100,15 @@ class ViewsContainer:
             view = self._get_view_albums(item_ids, [])
         elif item_ids[0] == Type.COMPILATIONS:
             view = self._get_view_albums([], item_ids)
+        elif item_ids[0] == Type.ARTISTS:
+            # Here we handle static items for RoundedArtistView
+            if data and data[0] < 0:
+                self.show_view(data)
+                return
+            elif data is None:
+                view = self._rounded_artists_view
+            else:
+                view = self._get_view_artists(item_ids, data)
         else:
             view = self._get_view_artists([], item_ids)
         view.show()
@@ -413,13 +422,11 @@ class ViewsContainer:
                 items += App().albums.get_albums_for_year(year)
             return [Album(album_id, [Type.YEARS], [])
                     for album_id in items]
+        from lollypop.view_albums_box import AlbumsBoxView
+        view_type = ViewType.SCROLLED
         if App().window.is_adaptive:
-            from lollypop.view_albums_list import AlbumsListView
-            view = AlbumsListView(ViewType.DEFAULT, years, [Type.YEARS])
-            view.set_margin_start(MARGIN_SMALL)
-        else:
-            from lollypop.view_albums_box import AlbumsBoxView
-            view = AlbumsBoxView([Type.YEARS], years)
+            view_type |= ViewType.MEDIUM
+        view = AlbumsBoxView([Type.YEARS], years, view_type)
         loader = Loader(target=load, view=view)
         loader.start()
         view.show()
@@ -436,13 +443,11 @@ class ViewsContainer:
             return [Album(album_id, genre_ids, artist_ids)
                     for album_id in album_ids]
 
+        from lollypop.view_albums_box import AlbumsBoxView
+        view_type = ViewType.SCROLLED
         if App().window.is_adaptive:
-            from lollypop.view_albums_list import AlbumsListView
-            view = AlbumsListView(ViewType.DEFAULT, genre_ids, artist_ids)
-            view.set_margin_start(MARGIN_SMALL)
-        else:
-            from lollypop.view_albums_box import AlbumsBoxView
-            view = AlbumsBoxView(genre_ids, artist_ids)
+            view_type |= ViewType.MEDIUM
+        view = AlbumsBoxView(genre_ids, artist_ids, view_type)
         loader = Loader(target=load, view=view)
         loader.start()
         view.show()
@@ -458,13 +463,11 @@ class ViewsContainer:
             album_ids += App().albums.get_synced_ids(index)
             return [Album(album_id) for album_id in album_ids]
 
+        from lollypop.view_albums_box import AlbumsBoxView
+        view_type = ViewType.SCROLLED
         if App().window.is_adaptive:
-            from lollypop.view_albums_list import AlbumsListView
-            view = AlbumsListView(ViewType.DEFAULT, [], [])
-            view.set_margin_start(MARGIN_SMALL)
-        else:
-            from lollypop.view_albums_box import AlbumsBoxView
-            view = AlbumsBoxView([], [])
+            view_type |= ViewType.MEDIUM
+        view = AlbumsBoxView([], [], view_type)
         loader = Loader(target=load, view=view)
         loader.start()
         view.show()
@@ -518,8 +521,9 @@ class ViewsContainer:
         """
         self._stack.destroy_children()
         App().window.emit("show-can-go-back", True)
-        state_two_ids = App().settings.get_value("state-two-ids")
         state_one_ids = App().settings.get_value("state-one-ids")
+        state_two_ids = App().settings.get_value("state-two-ids")
+        state_three_ids = App().settings.get_value("state-three-ids")
         # We do not support genres in navigation mode
         sidebar_content = App().settings.get_enum("sidebar-content")
         if sidebar_content == SidebarContent.GENRES and\
@@ -534,17 +538,15 @@ class ViewsContainer:
         if self._rounded_artists_view is None:
             self._rounded_artists_view = self._get_view_artists_rounded(True)
             self._stack.set_visible_child(self._rounded_artists_view)
-        if state_one_ids and state_two_ids:
-            if state_one_ids and state_one_ids[0] == Type.ALBUM:
-                album = Album(state_two_ids[0])
-                self.show_view([Type.ALBUM], album)
-            else:
-                self.show_view(state_one_ids, None, False)
-                self.show_view(state_one_ids, state_two_ids)
-        elif state_one_ids and state_one_ids[0] != Type.ARTISTS:
+        if state_one_ids and state_two_ids and state_three_ids:
+            self.show_view(state_one_ids, None, False)
+            album = Album(state_three_ids[0], state_one_ids, state_two_ids)
+            self.show_view([Type.ALBUM], album)
+        elif state_one_ids and state_two_ids:
+            self.show_view(state_one_ids, None, False)
+            self.show_view(state_one_ids, state_two_ids)
+        elif state_one_ids:
             self.show_view(state_one_ids)
-        elif state_two_ids:
-            self.show_view(state_two_ids)
         else:
             App().window.emit("can-go-back-changed", False)
             self._stack.set_visible_child(self._rounded_artists_view)
