@@ -56,16 +56,21 @@ class FullScreen(Gtk.Window, AdaptiveWindow, InformationController,
         monitor = screen.get_monitor_at_window(App().main_window.get_window())
         geometry = screen.get_monitor_geometry(monitor)
         self.__overlay_grid = builder.get_object("overlay_grid")
+        art_size_fs = ArtSize.FULLSCREEN / self.get_scale_factor()
+        font_size_fs = 11 / self.get_scale_factor()
         if geometry.width > geometry.height:
-            self.__art_size = int(ArtSize.FULLSCREEN * geometry.height / 1080)
-            self.__font_size = int(11 * geometry.height / 1080)
+            self.__art_size = int(art_size_fs * geometry.height / 1080)
+            self.__font_size = int(font_size_fs * geometry.height / 1080)
         else:
-            self.__art_size = int(ArtSize.FULLSCREEN * geometry.width / 1920)
-            self.__font_size = int(11 * geometry.width / 1920)
+            self.__art_size = int(art_size_fs * geometry.width / 1920)
+            self.__font_size = int(font_size_fs * geometry.width / 1920)
         widget = builder.get_object("widget")
         self._play_button = builder.get_object("play_btn")
         self._next_button = builder.get_object("next_btn")
         self._prev_button = builder.get_object("prev_btn")
+        if App().player.current_track.id == Type.RADIOS:
+            self._next_button.hide()
+            self._prev_button.hide()
         self._play_image = builder.get_object("play_image")
         self._pause_image = builder.get_object("pause_image")
         close_btn = builder.get_object("close_btn")
@@ -332,7 +337,16 @@ class FullScreen(Gtk.Window, AdaptiveWindow, InformationController,
             behaviour |= (ArtBehaviour.CROP | ArtBehaviour.DARKER)
             # We don't want this for background, stored for album cover
             behaviour &= ~ArtBehaviour.ROUNDED
-            if not album_artwork and\
+            if App().player.current_track.id == Type.RADIOS:
+                App().art_helper.set_radio_artwork(
+                                    App().player.current_track.radio_name,
+                                    allocation.width,
+                                    allocation.height,
+                                    self.get_scale_factor(),
+                                    behaviour | ArtBehaviour.BLUR_MAX,
+                                    self.__on_artwork,
+                                    False)
+            elif not album_artwork and\
                     App().settings.get_value("artist-artwork"):
                 if App().player.current_track.album.artists:
                     artist = App().player.current_track.album.artists[0]
