@@ -24,6 +24,41 @@ from lollypop.utils import get_icon_name, on_query_tooltip
 from lollypop.shown import ShownLists, ShownPlaylists
 
 
+class TypeAheadPopover(Gtk.Popover):
+    """
+        Special popover for find as type
+    """
+
+    def __init__(self):
+        """
+            Init popover
+        """
+        Gtk.Popover.__init__(self)
+        self.__entry = Gtk.Entry()
+        self.__entry.show()
+        self.add(self.__entry)
+        self.get_style_context().add_class("padding")
+        self.connect("unmap", self.__on_unmap)
+
+    @property
+    def entry(self):
+        """
+            Get popover entry
+            @return Gtk.Entry
+        """
+        return self.__entry
+
+#######################
+# PRIVATE             #
+#######################
+    def __on_unmap(self, popover):
+        """
+            Clear entry
+            @param popover as Gtk.popover
+        """
+        self.__entry.set_text("")
+
+
 class SelectionListRow(Gtk.ListBoxRow):
     """
         A selection list row
@@ -61,6 +96,7 @@ class SelectionListRow(Gtk.ListBoxRow):
 
         if rowid == Type.SEPARATOR:
             height = -1
+            self.set_sensitive(False)
         elif self.__mask & SelectionListMask.ARTISTS and\
                 self.__rowid >= 0 and\
                 App().settings.get_value("artist-artwork"):
@@ -202,7 +238,6 @@ class SelectionList(LazyLoadingView):
         A list for artists/genres
     """
     __gsignals__ = {
-        "item-selected": (GObject.SignalFlags.RUN_FIRST, None, ()),
         "populated": (GObject.SignalFlags.RUN_FIRST, None, ()),
         "pass-focus": (GObject.SignalFlags.RUN_FIRST, None, ())
     }
@@ -216,30 +251,35 @@ class SelectionList(LazyLoadingView):
         self.__base_type = base_type
         self.__sort = False
         self.__mask = 0
-        self.__selected_ids = []
         self.__height = SelectionListRow.get_best_height(self)
-        self.__listbox = Gtk.ListBox()
-        self.__listbox.connect("row-selected", self.__on_row_selected)
-        self.__listbox.connect("button-release-event",
-                               self.__on_button_release_event)
-        self.__listbox.connect("key-press-event",
-                               self.__on_key_press_event)
-        self.__listbox.set_sort_func(self.__sort_func)
-        self.__listbox.set_selection_mode(Gtk.SelectionMode.MULTIPLE)
-        self.__listbox.show()
-        self._viewport.add(self.__listbox)
+        self._listbox = Gtk.ListBox()
+        self._listbox.connect("button-release-event",
+                              self.__on_button_release_event)
+        self._listbox.connect("key-press-event",
+                              self.__on_key_press_event)
+        self._listbox.set_sort_func(self.__sort_func)
+        self._listbox.set_selection_mode(Gtk.SelectionMode.MULTIPLE)
+        self._listbox.set_filter_func(self._filter_func)
+        self._listbox.show()
+        self._viewport.add(self._listbox)
         overlay = Gtk.Overlay.new()
         overlay.set_hexpand(True)
         overlay.set_vexpand(True)
         overlay.show()
         overlay.add(self._scrolled)
-        self.__fastscroll = FastScroll(self.__listbox,
+        self.__fastscroll = FastScroll(self._listbox,
                                        self._scrolled)
         overlay.add_overlay(self.__fastscroll)
         self.add(overlay)
         self.get_style_context().add_class("sidebar")
         App().art.connect("artist-artwork-changed",
                           self.__on_artist_artwork_changed)
+        self.__type_ahead_popover = TypeAheadPopover()
+        self.__type_ahead_popover.set_relative_to(self._scrolled)
+        self.__type_ahead_popover.entry.connect("activate",
+                                                self.__on_type_ahead_activate)
+        self.__type_ahead_popover.entry.connect("changed",
+                                                self.__on_type_ahead_changed)
 
     def mark_as(self, type):
         """
@@ -263,7 +303,7 @@ class SelectionList(LazyLoadingView):
             Remove id from list
             @param object_id as int
         """
-        for child in self.__listbox.get_children():
+        for child in self._listbox.get_children():
             if child.id == object_id:
                 child.destroy()
                 break
@@ -275,7 +315,7 @@ class SelectionList(LazyLoadingView):
         """
         self.__sort = True
         # Do not add value if already exists
-        for child in self.__listbox.get_children():
+        for child in self._listbox.get_children():
             if child.id == value[0]:
                 return
         row = self.__add_value(value[0], value[1], value[2])
@@ -288,7 +328,7 @@ class SelectionList(LazyLoadingView):
             @param name as str
         """
         found = False
-        for child in self.__listbox.get_children():
+        for child in self._listbox.get_children():
             if child.id == object_id:
                 child.set_label(name)
                 found = True
@@ -309,11 +349,11 @@ class SelectionList(LazyLoadingView):
             self.__fastscroll.clear()
         # Remove not found items
         value_ids = set([v[0] for v in values])
-        for child in self.__listbox.get_children():
+        for child in self._listbox.get_children():
             if child.id not in value_ids:
                 self.remove_value(child.id)
         # Add items which are not already in the list
-        item_ids = set([child.id for child in self.__listbox.get_children()])
+        item_ids = set([child.id for child in self._listbox.get_children()])
         for value in values:
             if not value[0] in item_ids:
                 row = self.__add_value(value[0], value[1], value[2])
@@ -326,26 +366,25 @@ class SelectionList(LazyLoadingView):
             Select listbox items
             @param ids as [int]
         """
-        self.__listbox.unselect_all()
-        if ids:
-            self.__selected_ids = ids
-            for row in self.__listbox.get_children():
-                if row.id in ids:
-                    self.__listbox.select_row(row)
-        else:
-            self.__selected_ids = []
+        self._listbox.unselect_all()
+        for row in self._listbox.get_children():
+            if row.id in ids:
+                self._listbox.select_row(row)
+        for row in self._listbox.get_selected_rows():
+            row.activate()
+            break
 
     def grab_focus(self):
         """
             Grab focus on treeview
         """
-        self.__listbox.grab_focus()
+        self._listbox.grab_focus()
 
     def clear(self):
         """
             Clear treeview
         """
-        for child in self.__listbox.get_children():
+        for child in self._listbox.get_children():
             child.destroy()
         self.__fastscroll.clear()
         self.__fastscroll.clear_chars()
@@ -384,10 +423,9 @@ class SelectionList(LazyLoadingView):
             Select first available item
         """
         try:
-            self.__listbox.unselect_all()
-            row = self.__listbox.get_children()[0]
-            self.__selected_ids = [row.id]
-            self.__listbox.select_row(row)
+            self._listbox.unselect_all()
+            row = self._listbox.get_children()[0]
+            row.activate()
         except Exception as e:
             Logger.warning("SelectionList::select_first(): %s", e)
 
@@ -395,9 +433,25 @@ class SelectionList(LazyLoadingView):
         """
             Redraw list
         """
-        for row in self.__listbox.get_children():
+        for row in self._listbox.get_children():
             row.set_artwork()
 
+    @property
+    def type_ahead_popover(self):
+        """
+            Type ahead popover
+            @return TypeAheadPopover
+        """
+        return self.__type_ahead_popover
+
+    @property
+    def listbox(self):
+        """
+            Get listbox
+            @return Gtk.ListBox
+        """
+        return self._listbox
+
     @property
     def should_destroy(self):
         """
@@ -420,7 +474,7 @@ class SelectionList(LazyLoadingView):
             Get items count in list
             @return int
         """
-        return len(self.__listbox.get_children())
+        return len(self._listbox.get_children())
 
     @property
     def selected_ids(self):
@@ -428,7 +482,7 @@ class SelectionList(LazyLoadingView):
             Get selected ids
             @return array of ids as [int]
         """
-        return self.__selected_ids
+        return [row.id for row in self._listbox.get_selected_rows()]
 
 #######################
 # PRIVATE             #
@@ -438,7 +492,7 @@ class SelectionList(LazyLoadingView):
             Scroll to row
             @param row as SelectionListRow
         """
-        coordinates = row.translate_coordinates(self.__listbox, 0, 0)
+        coordinates = row.translate_coordinates(self._listbox, 0, 0)
         if coordinates:
             self._scrolled.get_vadjustment().set_value(coordinates[1])
 
@@ -459,12 +513,9 @@ class SelectionList(LazyLoadingView):
             self.emit("populated")
             GLib.idle_add(self.lazy_loading)
             # Scroll to first selected item
-            if self.__selected_ids:
-                selected_id = self.__selected_ids[0]
-                for row in self.__listbox.get_children():
-                    if row.id == selected_id:
-                        GLib.idle_add(self.__scroll_to_row, row)
-                        break
+            for row in self._listbox.get_selected_rows():
+                GLib.idle_add(self.__scroll_to_row, row)
+                break
 
     def __add_value(self, rowid, name, sortname):
         """
@@ -480,7 +531,7 @@ class SelectionList(LazyLoadingView):
         row = SelectionListRow(rowid, name, sortname,
                                self.__mask, self.__height)
         row.show()
-        self.__listbox.add(row)
+        self._listbox.add(row)
         return row
 
     def __sort_func(self, row_a, row_b):
@@ -513,10 +564,10 @@ class SelectionList(LazyLoadingView):
                 b = row_b.name
             return strcoll(a, b)
 
-    def __on_key_press_event(self, entry, event):
+    def __on_key_press_event(self, listbox, event):
         """
-            Forward to popover history listbox if needed
-            @param entry as Gtk.Entry
+            Pass focus as signal
+            @param listbox as Gtk.ListBox
             @param event as Gdk.Event
         """
         if event.keyval in [Gdk.KEY_Left, Gdk.KEY_Right]:
@@ -545,23 +596,21 @@ class SelectionList(LazyLoadingView):
                 rect.width = rect.height = 1
                 popover.set_pointing_to(rect)
                 popover.popup()
+                return True
         elif event.button == 1:
             state = event.get_state()
             static_selected = self.selected_ids and self.selected_ids[0] < 0
             if (not state & Gdk.ModifierType.CONTROL_MASK and
                     not state & Gdk.ModifierType.SHIFT_MASK) or\
                     static_selected:
-                listbox.unselect_all()
-                self.__selected_ids = []
+                listbox.set_selection_mode(Gtk.SelectionMode.SINGLE)
             row = listbox.get_row_at_y(event.y)
             if row is not None and not (row.id < 0 and self.selected_ids):
                 # User clicked on random, clear cached one
                 if row.id == Type.RANDOMS:
                     App().albums.clear_cached_randoms()
                     App().tracks.clear_cached_randoms()
-                self.__selected_ids.append(row.id)
-                listbox.select_row(row)
-        return True
+            listbox.set_selection_mode(Gtk.SelectionMode.MULTIPLE)
 
     def __on_artist_artwork_changed(self, art, artist):
         """
@@ -570,16 +619,38 @@ class SelectionList(LazyLoadingView):
             @param artist as str
         """
         if self.__mask & SelectionListMask.ARTISTS:
-            for row in self.__listbox.get_children():
+            for row in self._listbox.get_children():
                 if row.id >= 0 and row.name == artist:
                     row.set_artwork()
                     break
 
-    def __on_row_selected(self, listbox, row):
+    def __on_type_ahead_activate(self, entry):
         """
-            Emit selected item signal
+            Close popover and activate row
+            @param entry as Gtk.Entry
         """
-        if row is None or not self.__selected_ids:
+        self._listbox.unselect_all()
+        self.__type_ahead_popover.popdown()
+        for row in self._listbox.get_children():
+            style_context = row.get_style_context()
+            if style_context.has_class("typeahead"):
+                row.activate()
+            style_context.remove_class("typeahead")
+
+    def __on_type_ahead_changed(self, entry):
+        """
+            Search row and scroll down
+            @param entry as Gtk.Entry
+        """
+        search = entry.get_text().lower()
+        for row in self._listbox.get_children():
+            style_context = row.get_style_context()
+            style_context.remove_class("typeahead")
+        if not search:
             return
-        if row.id == self.__selected_ids[-1]:
-            self.emit("item-selected")
+        for row in self._listbox.get_children():
+            if row.name.lower().find(search) != -1:
+                style_context = row.get_style_context()
+                style_context.add_class("typeahead")
+                GLib.idle_add(self.__scroll_to_row, row)
+                break
