@@ -41,7 +41,7 @@ class Discoverer:
     def get_info(self, uri):
         """
             Return information for file at uri
-            @param path as str
+            @param uri as str
             @Exception GLib.Error
             @return GstPbutils.DiscovererInfo
         """
@@ -111,6 +111,7 @@ class TagReader(Discoverer):
         """
             Get MusicBrainz ID
             @param tags as Gst.TagList
+            @param name as str
             @return str
         """
         if tags is None or not name:
@@ -466,7 +467,6 @@ class TagReader(Discoverer):
     def get_lyrics(self, tags):
         """
             Return lyrics for tags
-            All this code sucks
             @parma tags as Gst.TagList
             @return lyrics as str
         """
@@ -534,11 +534,60 @@ class TagReader(Discoverer):
             lyrics = get_ogg()
         return lyrics
 
+    def get_synced_lyrics(self, tags):
+        """
+            Return synced lyrics for tags
+            @parma tags as Gst.TagList
+            @return lyrics as ([str, int])
+        """
+        def decode_lyrics(bytes_list, encoding):
+            lyrics = []
+            from lollypop.utils import decodeUnicode, splitUnicode
+            try:
+                for frame in bytes_list:
+                    (l, t) = splitUnicode(frame, encoding)
+                    if l:
+                        lyrics.append((decodeUnicode(l, encoding),
+                                       int.from_bytes(t[1:4], "big")))
+            except Exception as e:
+                Logger.warning("TagReader::get_synced_lyrics1(): %s", e)
+            return lyrics
+
+        def get_id3():
+            try:
+                size = tags.get_tag_size("private-id3v2-frame")
+                for i in range(0, size):
+                    (exists, sample) = tags.get_sample_index(
+                        "private-id3v2-frame",
+                        i)
+                    if not exists:
+                        continue
+                    (exists, m) = sample.get_buffer().map(Gst.MapFlags.READ)
+                    if not exists:
+                        continue
+                    prefix = (m.data[0:4])
+                    if prefix not in [b"SYLT"]:
+                        continue
+                    frame = m.data[10:]
+                    encoding = frame[0:1]
+                    string = decode_lyrics(frame.split(b"\n"), encoding)
+                    if string is not None:
+                        return string
+            except Exception as e:
+                Logger.error("TagReader::get_synced_lyrics2(): %s" % e)
+            return ""
+
+        if tags is None:
+            return ""
+        lyrics = get_id3()
+        return lyrics
+
     def add_artists(self, artists, sortnames, mb_artist_ids=""):
         """
             Add artists to db
             @param artists as [string]
             @param sortnames as [string]
+            @param mb_artist_ids as [string]
             @return [int]
             @commit needed
         """
@@ -598,16 +647,17 @@ class TagReader(Discoverer):
         return genre_ids
 
     def add_album(self, album_name, mb_album_id, artist_ids,
-                  uri, loved, popularity, rate, mtime):
+                  uri, loved, popularity, rate, synced, mtime):
         """
             Add album to db
-            @param album name as str
-            @param album artist_ids as [int]
+            @param album_name as str
+            @param mb_album_id as str
+            @param artist_ids as [int]
             @param uri as str
-            @param year as int
             @param loved as bool
             @param popularity as int
             @param rate as int
+            @param synced as int
             @param mtime as int
             @return (added as bool, album_id as int)
             @commit needed
@@ -621,7 +671,7 @@ class TagReader(Discoverer):
             added = True
             album_id = App().albums.add(album_name, mb_album_id, artist_ids,
                                         parent_uri, loved, popularity,
-                                        rate, mtime)
+                                        rate, synced, mtime)
         # Now we have our album id, check if path doesn"t change
         if App().albums.get_uri(album_id) != parent_uri:
             App().albums.set_uri(album_id, parent_uri)
