@@ -14,9 +14,10 @@ from gi.repository import Gtk, Gio, GLib
 
 from gettext import gettext as _
 
-from lollypop.pop_next import NextPopover
 from lollypop.pop_appmenu import AppMenuPopover
+from lollypop.pop_devices import DevicesPopover
 from lollypop.define import App, Shuffle, Repeat
+from lollypop.progressbar import ButtonProgressBar
 
 
 class ToolbarEnd(Gtk.Bin):
@@ -31,10 +32,10 @@ class ToolbarEnd(Gtk.Bin):
         Gtk.Bin.__init__(self)
         self.set_hexpand(True)
         self.__search_popover = None
+        self.__devices_popover = None
         self.__timeout_id = None
         builder = Gtk.Builder()
         builder.add_from_resource("/org/gnome/Lollypop/ToolbarEnd.ui")
-
         self.__party_submenu = builder.get_object("party_submenu")
         self.add(builder.get_object("end"))
 
@@ -57,8 +58,9 @@ class ToolbarEnd(Gtk.Bin):
         App().add_action(self.__shuffle_action)
         App().add_action(self.__repeat_action)
 
-        self.__shuffle_button = builder.get_object("shuffle-button")
-        self.__shuffle_image = builder.get_object("shuffle-button-image")
+        self.__shuffle_button = builder.get_object("shuffle_button")
+        self.__shuffle_button_image = builder.get_object(
+            "shuffle_button_image")
         shuffle_button_action = Gio.SimpleAction.new("shuffle-button", None)
         shuffle_button_action.connect("activate",
                                       self.__on_shuffle_button_activate)
@@ -85,35 +87,32 @@ class ToolbarEnd(Gtk.Bin):
         App().add_action(scrobbling_action)
         App().set_accels_for_action("app.scrobbling", ["<Control><Shift>s"])
 
-        self.__next_popover = NextPopover()
-        self.__next_popover.set_relative_to(self.__shuffle_button)
-
-        self.__search_button = builder.get_object("search-button")
+        self.__search_button = builder.get_object("search_button")
 
         search_action = App().lookup_action("search")
         search_action.connect("activate", self.__on_search_activate)
 
-        self.__list_button = builder.get_object("list-button")
+        self.__list_button = builder.get_object("list_button")
         self.__list_button.set_property("has-tooltip", True)
         self.__list_button.connect("query-tooltip",
                                    self.__on_list_button_query_tooltip)
-        self.__home_button = builder.get_object("home-button")
+        self.__home_button = builder.get_object("home_button")
         App().player.connect("playlist-changed", self.__on_playlist_changed)
         self.__set_shuffle_icon()
-        builder.connect_signals(self)
 
-    def on_next_changed(self, player):
-        """
-            Show next popover
-            @param player as Player
-        """
-        if self.__next_popover.should_be_shown():
-            if self.__next_popover.is_visible():
-                self.__next_popover.update()
-            else:
-                self.__next_popover.popup()
-        else:
-            self.__next_popover.hide()
+        button_progress_bar = ButtonProgressBar()
+        overlay = builder.get_object("overlay")
+        overlay.add_overlay(button_progress_bar)
+        overlay.set_overlay_pass_through(button_progress_bar, True)
+        devices_button = builder.get_object("devices_button")
+        self.__devices_popover = DevicesPopover(button_progress_bar)
+        self.__devices_popover.connect(
+                "closed", self.__on_popover_closed, devices_button)
+        self.__devices_popover.connect("content-changed",
+                                       self.__on_devices_content_changed,
+                                       devices_button)
+        self.__devices_popover.populate()
+        builder.connect_signals(self)
 
     def set_mini(self, mini):
         """
@@ -137,6 +136,14 @@ class ToolbarEnd(Gtk.Bin):
         self.__on_search_button_cancelled()
         self.__search_popover.set_text(search)
 
+    @property
+    def devices_popover(self):
+        """
+            Get Devices Popover
+            @return AppMenuPopover
+        """
+        return self.__devices_popover
+
     @property
     def home_button(self):
         """
@@ -145,26 +152,16 @@ class ToolbarEnd(Gtk.Bin):
         """
         return self.__home_button
 
-    @property
-    def next_popover(self):
-        """
-            Get next popover
-            @return popover
-        """
-        return self.__next_popover
-
 #######################
 # PROTECTED           #
 #######################
     def _on_list_button_toggled(self, button):
         """
             Show current playback context popover
-            @param button as Gtk.MenuButton
+            @param button as Gtk.ToggleButton
         """
         if not button.get_active():
             return
-        self.__next_popover.hide()
-        self.__next_popover.inhibit(True)
         from lollypop.pop_current import CurrentPopover
         popover = CurrentPopover()
         popover.set_relative_to(button)
@@ -182,55 +179,48 @@ class ToolbarEnd(Gtk.Bin):
     def _on_search_button_toggled(self, button):
         """
             Show search popover
-            @param button as Gtk.Button
+            @param button as Gtk.ToggleButton
         """
-        if not button.get_active():
-            self.__search_popover.popdown()
-            return
-        self.__next_popover.hide()
-        self.__next_popover.inhibit(True)
-        if self.__search_popover is None:
-            from lollypop.pop_search import SearchPopover
-            self.__search_popover = SearchPopover()
-            self.__search_popover.connect("closed",
-                                          self.__on_popover_closed,
-                                          button)
-        self.__search_popover.set_relative_to(button)
-        self.__search_popover.popup()
-        return True
+        if button.get_active():
+            if self.__search_popover is None:
+                from lollypop.pop_search import SearchPopover
+                self.__search_popover = SearchPopover()
+                self.__search_popover.connect("closed",
+                                              self.__on_popover_closed,
+                                              button)
+            self.__search_popover.set_relative_to(button)
+            self.__search_popover.popup()
 
     def _on_shuffle_button_toggled(self, button):
         """
-           Create submenu
-           @param button as Gtk.MenuButton
+           Popup shuffle menu
+           @param button as Gtk.ToggleButton
         """
         if button.get_active():
             # Create submenu "Configure party mode"
             self.__party_submenu.remove_all()
             self.__init_party_submenu()
-            self.__next_popover.hide()
-            self.__next_popover.inhibit(True)
-        else:
-            self.__next_popover.inhibit(False)
-            if self.__next_popover.should_be_shown():
-                self.__next_popover.popup()
+
+    def _on_devices_button_toggled(self, button):
+        """
+           Create submenu
+           @param button as Gtk.ToggleButton
+        """
+        if button.get_active():
+            self.__devices_popover.set_relative_to(button)
+            self.__devices_popover.popup()
 
     def _on_settings_button_toggled(self, button):
         """
-           Create submenu
-           @param button as Gtk.MenuButton
+           Popup application menu
+           @param button as Gtk.ToggleButton
         """
         if button.get_active():
-            popover = AppMenuPopover()
-            popover.set_relative_to(button)
-            popover.connect("closed", self.__on_popover_closed, button)
-            popover.popup()
-            self.__next_popover.hide()
-            self.__next_popover.inhibit(True)
-        else:
-            self.__next_popover.inhibit(False)
-            if self.__next_popover.should_be_shown():
-                self.__next_popover.popup()
+            appmenu_popover = AppMenuPopover()
+            appmenu_popover.connect(
+                "closed", self.__on_popover_closed, button)
+            appmenu_popover.set_relative_to(button)
+            appmenu_popover.popup()
 
 #######################
 # PRIVATE             #
@@ -308,28 +298,31 @@ class ToolbarEnd(Gtk.Bin):
         shuffle = App().settings.get_enum("shuffle")
         repeat = App().settings.get_enum("repeat")
         if repeat == Repeat.TRACK:
-            self.__shuffle_image.get_style_context().remove_class("selected")
-            self.__shuffle_image.set_from_icon_name(
+            self.__shuffle_button_image.get_style_context().remove_class(
+                "selected")
+            self.__shuffle_button_image.set_from_icon_name(
                 "media-playlist-repeat-song-symbolic",
                 Gtk.IconSize.SMALL_TOOLBAR)
         elif shuffle == Shuffle.NONE:
-            self.__shuffle_image.get_style_context().remove_class("selected")
+            self.__shuffle_button_image.get_style_context().remove_class(
+                "selected")
             if repeat == Repeat.ALL:
-                self.__shuffle_image.set_from_icon_name(
+                self.__shuffle_button_image.set_from_icon_name(
                     "media-playlist-repeat-symbolic",
                     Gtk.IconSize.SMALL_TOOLBAR)
             else:
-                self.__shuffle_image.set_from_icon_name(
+                self.__shuffle_button_image.set_from_icon_name(
                     "media-playlist-consecutive-symbolic",
                     Gtk.IconSize.SMALL_TOOLBAR)
         else:
-            self.__shuffle_image.set_from_icon_name(
+            self.__shuffle_button_image.set_from_icon_name(
                 "media-playlist-shuffle-symbolic",
                 Gtk.IconSize.SMALL_TOOLBAR)
             if shuffle == Shuffle.TRACKS:
-                self.__shuffle_image.get_style_context().add_class("selected")
+                self.__shuffle_button_image.get_style_context().add_class(
+                    "selected")
             else:
-                self.__shuffle_image.get_style_context().remove_class(
+                self.__shuffle_button_image.get_style_context().remove_class(
                     "selected")
 
     def __on_party_mode_change_state(self, action, value):
@@ -346,7 +339,6 @@ class ToolbarEnd(Gtk.Bin):
         action.set_state(value)
         self.__shuffle_action.set_enabled(not value)
         self.__repeat_action.set_enabled(not value)
-        self.on_next_changed(App().player)
 
     def __on_scrobbling_mode_change_state(self, action, value):
         """
@@ -392,18 +384,14 @@ class ToolbarEnd(Gtk.Bin):
             @param value as GLib.Variant
         """
         self.__set_shuffle_icon()
-        self.__next_popover.hide()
 
     def __on_popover_closed(self, popover, button):
         """
-            Restore next popover if needed
+            Restore button state
             @param popover as Popover
             @param button as Gtk.Button
         """
         button.set_active(False)
-        self.__next_popover.inhibit(False)
-        if self.__next_popover.should_be_shown():
-            self.__next_popover.popup()
 
     def __on_search_activate(self, action, variant):
         """
@@ -441,3 +429,15 @@ class ToolbarEnd(Gtk.Bin):
             self.__list_button.set_sensitive(True)
         else:
             self.__list_button.set_sensitive(False)
+
+    def __on_devices_content_changed(self, popover, count, devices_button):
+        """
+            Hide/Show button
+            @param popover as DevicesPopover
+            @param count as int
+            @param devices_button as Gtk.ToggleButton
+        """
+        if count:
+            devices_button.show()
+        else:
+            devices_button.hide()
