@@ -69,13 +69,12 @@ class View(BaseView, Gtk.Grid):
             self.__search_entry.connect("search-changed",
                                         self._on_search_changed)
             self.__search_entry.connect("key-press-event",
-                                        self.__on_key_press)
-            self.__search_entry.set_size_request(300, -1)
+                                        self.__on_key_press_event)
             self.__search_entry.show()
             button = Gtk.Button.new_from_icon_name("window-close-symbolic",
                                                    Gtk.IconSize.MENU)
             button.set_relief(Gtk.ReliefStyle.NONE)
-            button.connect("clicked", self.__on_button_clicked)
+            button.connect("clicked", lambda x: self.__close_search_widget())
             button.show()
             grid.add(self.__search_entry)
             grid.add(button)
@@ -134,8 +133,12 @@ class View(BaseView, Gtk.Grid):
         """
         if self._filter is not None:
             enable = not self.__search_bar.get_search_mode()
+            if enable:
+                width = self.get_allocated_width()
+                self.__search_entry.set_size_request(min(300, width / 2), -1)
             self.__search_bar.show() if enable else self.__search_bar.hide()
             self.__search_bar.set_search_mode(enable)
+            App().enable_special_shortcuts(not enable)
             if enable:
                 self.__search_entry.grab_focus()
 
@@ -214,35 +217,42 @@ class View(BaseView, Gtk.Grid):
         pass
 
     def _on_map(self, widget):
-        pass
+        """
+            Handles special shortcuts
+            @param widget as Gtk.Widget
+        """
+        if self._filter is not None and self.__search_bar.get_search_mode():
+            App().enable_special_shortcuts(False)
 
     def _on_unmap(self, widget):
-        pass
+        """
+            Handles special shortcuts
+            @param widget as Gtk.Widget
+        """
+        if self._filter is not None and self.__search_bar.get_search_mode():
+            App().enable_special_shortcuts(True)
 
 #######################
 # PRIVATE             #
 #######################
-    def __on_button_clicked(self, widget):
+    def __close_search_widget(self):
         """
-            Hide widget, why GTK doesn"t do that?
-            Otherwise, we get an ugly frame
-            @param widget as Gtk.Button
+            Close search widget
         """
         self.__search_entry.set_text("")
         self.__search_bar.set_search_mode(False)
         self.__search_bar.hide()
+        App().enable_special_shortcuts(True)
 
-    def __on_key_press(self, widget, event):
+    def __on_key_press_event(self, widget, event):
         """
-            If Esc, hide widget, why GTK doesn"t do that?
+            If Esc, hide widget, why GTK doesn't do that?
             Otherwise, we get an ugly frame
             @param widget as Gtk.SearchEntry
             @param event as Gdk.Event
         """
         if event.keyval == 65307:
-            self.__search_entry.set_text("")
-            self.__search_bar.set_search_mode(False)
-            self.__search_bar.hide()
+            self.__close_search_widget()
             return True
 
     def __on_leave_notify(self, widget, event):
@@ -293,9 +303,10 @@ class LazyLoadingView(View):
         """
             Stop loading
         """
-        self.__backup_queue = self._lazy_queue + self.__priority_queue
-        self._lazy_queue = []
-        self.__priority_queue = []
+        if self._lazy_queue or self.__priority_queue:
+            self.__backup_queue = self._lazy_queue + self.__priority_queue
+            self._lazy_queue = []
+            self.__priority_queue = []
         View.stop(self)
 
     def lazy_loading(self):
@@ -323,6 +334,7 @@ class LazyLoadingView(View):
             Restore backup and load
             @param widget as Gtk.Widget
         """
+        View._on_map(self, widget)
         if self.__backup_queue:
             self._lazy_queue = self.__backup_queue
             GLib.idle_add(self.lazy_loading)
