@@ -472,12 +472,12 @@ class AlbumsListView(LazyLoadingView, ViewController):
         View showing albums
     """
 
-    def __init__(self, view_type, genre_ids=[], artist_ids=[]):
+    def __init__(self, genre_ids, artist_ids, view_type):
         """
             Init widget
-            @param view_type as ViewType
             @param genre_ids as int
             @param artist_ids as int
+            @param view_type as ViewType
         """
         LazyLoadingView.__init__(self, view_type | ViewType.FILTERED)
         ViewController.__init__(self, ViewControllerType.ALBUM)
@@ -670,6 +670,7 @@ class AlbumsListView(LazyLoadingView, ViewController):
             Connect signals and set active ids
             @param widget as Gtk.Widget
         """
+        LazyLoadingView._on_map(self, widget)
         if not self.__genre_ids and not self.__artist_ids:
             return
         if self.__genre_ids:
@@ -682,6 +683,8 @@ class AlbumsListView(LazyLoadingView, ViewController):
                                      GLib.Variant("ai", self.__artist_ids))
             App().settings.set_value("state-two-ids",
                                      GLib.Variant("ai", []))
+        App().settings.set_value("state-three-ids",
+                                 GLib.Variant("ai", []))
 
 #######################
 # PRIVATE             #
