@@ -167,6 +167,8 @@ class ArtistView(ArtistAlbumsView, ArtistViewCommon):
                                  GLib.Variant("ai", self._genre_ids))
         App().settings.set_value("state-two-ids",
                                  GLib.Variant("ai", self._artist_ids))
+        App().settings.set_value("state-three-ids",
+                                 GLib.Variant("ai", []))
 
     def _on_unmap(self, widget):
         """
