@@ -98,7 +98,7 @@ class RoundedArtistsView(FlowBoxView):
         """
         App().window.emit("show-can-go-back", True)
         App().window.emit("can-go-back-changed", True)
-        App().window.container.show_view([widget.data])
+        App().window.container.show_view([Type.ARTISTS], [widget.data])
 
     def _on_map(self, widget):
         """
@@ -109,6 +109,8 @@ class RoundedArtistsView(FlowBoxView):
                                  GLib.Variant("ai", [Type.ARTISTS]))
         App().settings.set_value("state-two-ids",
                                  GLib.Variant("ai", []))
+        App().settings.set_value("state-three-ids",
+                                 GLib.Variant("ai", []))
         self.__art_signal_id = App().art.connect(
                                               "artist-artwork-changed",
                                               self.__on_artist_artwork_changed)
