@@ -14,7 +14,7 @@ from gi.repository import Gtk
 
 from random import shuffle
 
-from lollypop.define import App, SelectionListMask, ArtHelperEffect
+from lollypop.define import App, SelectionListMask, ArtBehaviour, Type
 from lollypop.utils import get_icon_name
 from lollypop.objects import Album
 from lollypop.widgets_flowbox_rounded import RoundedFlowBoxWidget
@@ -92,6 +92,9 @@ class RoundedArtistWidget(RoundedFlowBoxWidget):
                                             self._art_size,
                                             self._art_size,
                                             self._artwork.get_scale_factor(),
+                                            ArtBehaviour.ROUNDED |
+                                            ArtBehaviour.CROP_SQUARE |
+                                            ArtBehaviour.CACHE,
                                             self.__on_artist_artwork)
         else:
             album_ids = App().albums.get_ids([self._data], [])
@@ -102,8 +105,10 @@ class RoundedArtistWidget(RoundedFlowBoxWidget):
                                             self._art_size,
                                             self._art_size,
                                             self._artwork.get_scale_factor(),
-                                            self.__on_artist_artwork,
-                                            ArtHelperEffect.ROUNDED)
+                                            ArtBehaviour.ROUNDED |
+                                            ArtBehaviour.CROP_SQUARE |
+                                            ArtBehaviour.CACHE,
+                                            self.__on_artist_artwork)
             else:
                 set_icon_name()
 
@@ -117,11 +122,14 @@ class RoundedArtistWidget(RoundedFlowBoxWidget):
         """
         if App().settings.get_value("show-sidebar"):
             return
-        from lollypop.pop_menu_views import ViewsMenuPopover
         from lollypop.view_artists_rounded import RoundedArtistsView
-        popover = ViewsMenuPopover(self.get_ancestor(RoundedArtistsView),
-                                   self.data,
-                                   SelectionListMask.ARTISTS_VIEW)
+        from lollypop.menu_selectionlist import SelectionListMenu
+        from lollypop.widgets_utils import Popover
+        menu = SelectionListMenu(self.get_ancestor(RoundedArtistsView),
+                                 self.data,
+                                 SelectionListMask.ARTISTS_VIEW)
+        popover = Popover()
+        popover.bind_model(menu, None)
         popover.set_relative_to(widget)
         popover.popup()
 
@@ -157,6 +165,10 @@ class RoundedArtistWidget(RoundedFlowBoxWidget):
             @param event as Gdk.Event
         """
         if event.button == 1:
+            # User clicked on random, clear cached one
+            if self._data == Type.RANDOMS:
+                App().albums.clear_cached_randoms()
+                App().tracks.clear_cached_randoms()
             self.activate()
         elif event.button == 3:
             self.__popup_menu(self)
