@@ -103,11 +103,14 @@ class PlaylistRoundedWidget(RoundedAlbumsWidget, OverlayPlaylistHelper):
             Popup menu for track
             @param widget as Gtk.Widget
         """
-        from lollypop.pop_menu_views import ViewsMenuPopover
         from lollypop.view_playlists_manager import PlaylistsManagerView
-        popover = ViewsMenuPopover(self.get_ancestor(PlaylistsManagerView),
-                                   self.data,
-                                   SelectionListMask.PLAYLISTS)
+        from lollypop.menu_selectionlist import SelectionListMenu
+        from lollypop.widgets_utils import Popover
+        menu = SelectionListMenu(self.get_ancestor(PlaylistsManagerView),
+                                 self.data,
+                                 SelectionListMask.PLAYLISTS)
+        popover = Popover()
+        popover.bind_model(menu, None)
         popover.set_relative_to(widget)
         popover.popup()
 
@@ -127,6 +130,10 @@ class PlaylistRoundedWidget(RoundedAlbumsWidget, OverlayPlaylistHelper):
             @param event as Gdk.Event
         """
         if event.button == 1:
+            # User clicked on random, clear cached one
+            if self._data == Type.RANDOMS:
+                App().albums.clear_cached_randoms()
+                App().tracks.clear_cached_randoms()
             self.activate()
         elif event.button == 3:
             self.__popup_menu(self)
