@@ -12,8 +12,7 @@
 
 from gi.repository import GObject, Gtk, Pango, GLib
 
-from lollypop.define import App, ArtSize, Type, ViewType
-from lollypop.pop_menu import TrackMenu
+from lollypop.define import App, ArtSize, Type, ViewType, ArtBehaviour
 from lollypop.widgets_row import Row
 from lollypop.widgets_row_dnd import DNDRow
 
@@ -112,6 +111,8 @@ class PlaylistRow(Row, DNDRow):
                                            ArtSize.MEDIUM,
                                            ArtSize.MEDIUM,
                                            self.__artwork.get_scale_factor(),
+                                           ArtBehaviour.CACHE |
+                                           ArtBehaviour.CROP_SQUARE,
                                            self.__on_album_artwork)
 
     def hide_artwork(self):
@@ -140,6 +141,7 @@ class PlaylistRow(Row, DNDRow):
         """
             Return TrackMenu
         """
+        from lollypop.menu_objects import TrackMenu
         return TrackMenu(self._track, True)
 
     def _on_destroy(self, widget):
