@@ -55,19 +55,8 @@ class Window(Gtk.ApplicationWindow, AdaptiveWindow):
         self.set_auto_startup_notification(False)
         self.connect("realize", self.__on_realize)
         self.connect("adaptive-changed", self.__on_adaptive_changed)
-
-    def do_event(self, event):
-        """
-            Update overlays as internal widget may not have received the signal
-            @param event as Gdk.event
-        """
-        if event.type == Gdk.EventType.FOCUS_CHANGE and\
-                self.__container.view is not None:
-            self.__container.view.disable_overlay()
-        if event.type == Gdk.EventType.BUTTON_RELEASE and\
-                event.button.button == 8:
-            App().window.go_back()
-        Gtk.ApplicationWindow.do_event(self, event)
+        self.connect("button-release-event", self.__on_button_release_event)
+        self.connect("focus-out-event", self.__on_focus_out_event)
 
     @property
     def miniplayer(self):
@@ -391,6 +380,24 @@ class Window(Gtk.ApplicationWindow, AdaptiveWindow):
             artists = ", ".join(player.current_track.artists)
             self.set_title("%s - %s" % (artists, "Lollypop"))
 
+    def __on_focus_out_event(self, window, event):
+        """
+            Disable overlay on children
+            @param window as Gtk.Window
+            @param event as Gdk.EventFocus
+        """
+        if self.__container.view is not None:
+            self.__container.view.disable_overlay()
+
+    def __on_button_release_event(self, window, event):
+        """
+            Handle special mouse buttons
+            @param window as Gtk.Window
+            @param event as Gdk.EventButton
+        """
+        if event.button == 8:
+            App().window.go_back()
+
     def __on_adaptive_changed(self, window, adaptive_stack):
         """
             Handle adaptive mode
